#[non_exhaustive]
pub enum Request { Destroy, LockPointer { id: New<ZwpLockedPointerV1>, surface: WlSurface, pointer: WlPointer, region: Option<WlRegion>, lifetime: WEnum<Lifetime>, }, ConfinePointer { id: New<ZwpConfinedPointerV1>, surface: WlSurface, pointer: WlPointer, region: Option<WlRegion>, lifetime: WEnum<Lifetime>, }, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Destroy

destroy the pointer constraints manager object

Used by the client to notify the server that it will no longer use this pointer constraints object.

This is a destructor, once received this object cannot be used any longer.



LockPointer

lock pointer to a position

The lock_pointer request lets the client request to disable movements of the virtual pointer (i.e. the cursor), effectively locking the pointer to a position. This request may not take effect immediately; in the future, when the compositor deems implementation-specific constraints are satisfied, the pointer lock will be activated and the compositor sends a locked event.

The protocol provides no guarantee that the constraints are ever satisfied, and does not require the compositor to send an error if the constraints cannot ever be satisfied. It is thus possible to request a lock that will never activate.

There may not be another pointer constraint of any kind requested or active on the surface for any of the wl_pointer objects of the seat of the passed pointer when requesting a lock. If there is, an error will be raised. See general pointer lock documentation for more details.

The intersection of the region passed with this request and the input region of the surface is used to determine where the pointer must be in order for the lock to activate. It is up to the compositor whether to warp the pointer or require some kind of user interaction for the lock to activate. If the region is null the surface input region is used.

A surface may receive pointer focus without the lock being activated.

The request creates a new object wp_locked_pointer which is used to interact with the lock as well as receive updates about its state. See the the description of wp_locked_pointer for further information.

Note that while a pointer is locked, the wl_pointer objects of the corresponding seat will not emit any wl_pointer.motion events, but relative motion events will still be emitted via wp_relative_pointer objects of the same seat. wl_pointer.axis and wl_pointer.button events are unaffected.

Fields

surface: WlSurface

surface to lock pointer to

pointer: WlPointer

the pointer that should be locked

region: Option<WlRegion>

region of surface

lifetime: WEnum<Lifetime>

lock lifetime



ConfinePointer

confine pointer to a region

The confine_pointer request lets the client request to confine the pointer cursor to a given region. This request may not take effect immediately; in the future, when the compositor deems implementation- specific constraints are satisfied, the pointer confinement will be activated and the compositor sends a confined event.

The intersection of the region passed with this request and the input region of the surface is used to determine where the pointer must be in order for the confinement to activate. It is up to the compositor whether to warp the pointer or require some kind of user interaction for the confinement to activate. If the region is null the surface input region is used.

The request will create a new object wp_confined_pointer which is used to interact with the confinement as well as receive updates about its state. See the the description of wp_confined_pointer for further information.

Fields

surface: WlSurface

surface to lock pointer to

pointer: WlPointer

the pointer that should be confined

region: Option<WlRegion>

region of surface

lifetime: WEnum<Lifetime>

confinement lifetime

Implementations



impl Request

pub fn opcode(&self) -> u16

Get the opcode number of this message