Struct ZwpPointerConstraintsV1
pub struct ZwpPointerConstraintsV1 { /* private fields */ }wayland and Linux only.Expand description
constrain the movement of a pointer
The global interface exposing pointer constraining functionality. It exposes two requests: lock_pointer for locking the pointer to its position, and confine_pointer for locking the pointer to a region.
The lock_pointer and confine_pointer requests create the objects wp_locked_pointer and wp_confined_pointer respectively, and the client can use these objects to interact with the lock.
For any surface, only one lock or confinement may be active across all wl_pointer objects of the same seat. If a lock or confinement is requested when another lock or confinement is active or requested on the same surface and with any of the wl_pointer objects of the same seat, an ‘already_constrained’ error will be raised.
See also the Request enum for this interface.